@@ -368,13 +368,17 @@ colon_s %>%
 library(knitr)
 kable(t, row.names=FALSE, align = c("l", "l", "r", "r", "r", "r", "r", "r"))
 
-## ---- warning=FALSE-----------------------------------------------------------
+## ----message=FALSE, warning=FALSE---------------------------------------------
 library(finalfit)
-explanatory = c("age", "age.factor", "sex.factor", "obstruct.factor")
+
+# Here, `extent` is a continuous variable with 4 distinct values. 
+# Any continuous variable with 5 or fewer unique values is converted silently to factor 
+# e.g.
+explanatory = c("extent")
 dependent = "mort_5yr"
 colon_s %>%
-  summary_factorlist(dependent, explanatory, p = TRUE, 
-  									 digits = c(1,2,3,4)) -> t
+  summary_factorlist(dependent, explanatory, 
+  									 cont_cut = 0) -> t
 
 ## ---- echo=FALSE--------------------------------------------------------------
 library(knitr)
@@ -403,7 +407,18 @@ kable(t, row.names=FALSE, align = c("l", "l", "l", "l", "r", "r", "r"))
 explanatory = c("age", "age.factor", "sex.factor", "obstruct.factor")
 dependent = "perfor.factor"
 colon_s %>%
-  summary_factorlist(dependent, explanatory, p = TRUE, digits = c(1,2,3,4)) -> t
+  summary_factorlist(dependent, explanatory, p = TRUE, digits = c(1,2,3,4,0)) -> t
+
+## ---- echo=FALSE--------------------------------------------------------------
+library(knitr)
+kable(t, row.names=FALSE, align = c("l", "l", "r", "r", "r", "r", "r", "r"))
+
+## ---- warning=FALSE-----------------------------------------------------------
+explanatory = c("age", "age.factor", "sex.factor", "obstruct.factor")
+dependent = "perfor.factor"
+colon_s %>%
+	mutate(my_weights = runif(929, 0, 1)) %>% # Random just to demonstrate
+	summary_factorlist(dependent, explanatory, weights = "my_weights", digits = c(1, 1, 3, 1, 1))-> t
 
 ## ---- echo=FALSE--------------------------------------------------------------
 library(knitr)
@@ -895,26 +910,10 @@ library(finalfit)
 library(dplyr)
 explanatory = c("age.factor", "sex.factor", "obstruct.factor", "perfor.factor")
 dependent = "mort_5yr"
-weights = runif(dim(colon_s)[1]) # random just for example
 
-# All in one pipe
 colon_s %>%
-	## Crosstable
-	summary_factorlist(dependent, explanatory, fit_id=TRUE)  %>% 
-	
-	## Add univariable
-	ff_merge(
-		glmuni(colon_s, dependent, explanatory, weights = weights, family = quasibinomial) %>%
-			fit2df(estimate_suffix=" (univariable)")
-	) %>% 
-	
-	## Add multivariable
-	ff_merge(
-		glmmulti(colon_s, dependent, explanatory, weights = weights, family = quasibinomial) %>%
-			fit2df(estimate_suffix=" (multivariable)"),
-		last_merge = TRUE
-	) %>% 
-	dependent_label(colon_s, dependent) -> t
+	mutate(myweights = runif(dim(colon_s)[1])) %>% # random just for example
+	finalfit(dependent, explanatory, weights = "myweights") -> t
 
 ## ---- echo=FALSE--------------------------------------------------------------
 library(knitr)
